@@ -125,10 +125,11 @@ class UnshortenIt(object):
                 token_re = re.findall(r'Token(.*?)\,', html)
                 if len(token_re) > 0:
                     token = re.sub(r'\:\s\'|\'$', '', token_re[0].strip())
-                ak_re = re.findall(r"params\[\'AuthKey\'\](.*?)\;", html)
+                ak_re = re.findall(r"params\[\'A(.*?)\;", html)
 
-                if len(ak_re) > 2:
-                    ak_1 = re.sub(r"\=\s|\'", '', ak_re[0].strip())
+                if len(ak_re) > 3:
+
+                    ak_1 = re.sub(r"[A-Za-z\+\s\]\=\']", '', ak_re[0].strip())
                     ak_2 = re.sub(r"(.*?)\+", '', ak_re[2].strip()).strip()
                     ak = int(ak_1) + int(ak_2)
 
